==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-clock/clock_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;založeno na místním nastavení data&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation>Nastavení hodin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Nastavení hodin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Ukázat sekundy</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12 &amp;hodinový styl</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Použít světový čas (UTC)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Formát data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Neukazovat datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Ukázat datum &amp;před časem</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Ukázat datum &amp;za časem</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Ukázat datum pod časem na novém řá&amp;dku</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>První den týdne v kalendáři</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Natočení</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Natočit automaticky, když je panel svisle</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Písmo</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation>Ukázat &amp;datum</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation>Formát d&amp;ata</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation>Pí&amp;smo</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation>Ukázat datum na &amp;novém řádku</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation>&amp;Použít písma motivu</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation>Písmo pro čas</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation>Písmo pro datum</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation>Hodně světlé</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Světlé</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation>Hodně černé</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Černé</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation>Polotučné</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Zadat vlastní formát data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;založeno na místním nastavení data&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Nastavení hodin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Nastavení hodin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Ukázat sekundy</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12 &amp;hodinový styl</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Použít světový čas (UTC)</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Formát data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>&amp;Neukazovat datum</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Ukázat datum &amp;před časem</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Ukázat datum &amp;za časem</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Ukázat datum pod časem na novém řá&amp;dku</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>První den týdne v kalendáři</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Natočení</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Natočit automaticky, když je panel svisle</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Písmo</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Písmo</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Ukázat &amp;datum</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Formát d&amp;ata</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Pí&amp;smo</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Ukázat datum na &amp;novém řádku</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Použít písma motivu</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Písmo pro čas</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Písmo pro datum</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Hodně světlé</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Světlé</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Hodně černé</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Černé</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Tučné</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Polotučné</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Kurzíva</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Zadat vlastní formát data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Vykládané posloupnosti formátu data jsou:

d	den jako číslo bez nuly na začátku (1 až 31).
dd	den jako číslo s nulou na začátku (01 až 31).
ddd	zkrácený název dne (např. Po až Ne).
dddd	dlouhý název dne (např Pondělí až Neděle).
M	měsíc jako číslo bez nuly na začátku (1-12).
MM	měsíc jako číslo s nulou na začátku (01-12).
MMM	zkrácený název měsíce (např. Led až Pro).
MMMM	dlouhý název měsíce (např. Leden až Prosinec).
yy	rok jako číslo ze dvou číslic (00-99).
yyyy	rok jako číslo ze čtyř číslic

Se všemi ostatními zadanými znaky se bude zacházet jako s textem.
Se všemi ostatními znakovými posloupnostmi uzavřenými v jednoduchých závorkách (&apos;)
se bude stejně tak zacházet jako s textem a nebudou se používat jako výraz.


Vlastní formát data:</translation>
    </message>
</context>
</TS>
